#!/bin/sh
# test we are root
if [ "$(id -u)" != "0" ]; then
   echo "This script must be run as root."
   exit 1
fi

export CFLAGS="-mtune=generic -Os -pipe"
export CXXFLAGS="-mtune=generic -Os -pipe -fno-exceptions -fno-rtti "

P=libxcb-errors
V=1.0.1
SRC=xcb-util-errors-1.0.1
USER=`cat /etc/sysconfig/tcuser`
LIST="compiletc submitqc libxcb-dev python3.9 git automake gettext-dev intltool gtk-doc libtool-dev util-macros"
for Z in $LIST
    do 
    su -c "tce-load -wil $Z" $USER | grep -v "already"
done



URL=https://xorg.freedesktop.org/archive/individual/lib
cd /tmp
su -c "/usr/local/bin/wget -nc --no-check-certificate \
$URL/xcb-util-errors-1.0.1.tar.xz"  $USER
tar xvf xcb*xz
cd $SRC
./configure --prefix=/usr/local 
find . -name Makefile -type f -exec sed -i 's/-g -O2//g' {} \; 
make -j4 # seconds
make install-strip DESTDIR=/tmp/$P 
cd /tmp

# dev
#####
mkdir -p $P-dev/usr/local/lib/
mv $P/usr/local/include $P-dev/usr/local/
mv $P/usr/local/lib/pkgconfig $P-dev/usr/local/lib/
mv $P/usr/local/lib/*.a $P-dev/usr/local/lib/
rm -rf  $P/usr/local/lib/*.la 

# main
#####
mkdir -p $P/usr/local/share/doc/$P/
cp $SRC/COPYING $P/usr/local/share/doc/$P/

# TCZ them
###########
LIST2="$P $P-dev "
for Z in $LIST2
do
	mksquashfs $Z $Z.tcz
	md5sum $Z.tcz > $Z.tcz.md5.txt
	cd $Z
	find usr -not -type d > /tmp/$Z.tcz.list
        sed 's|usr|/usr|g' -i /tmp/$Z.tcz.list
	cd /tmp
done

ls -hal

cat >> $P-dev.tcz.info <<'EOF'
Title:          libxcb-errors-dev.tcz
Description:    dev files
Version:        1.0.1
Author:         Uli Schlachter 
Original-site:  https://xorg.freedesktop.org/archive/individual/lib/
Copying-policy: accompanied 
Size:           16K 
Extension_by:   aus9 @linuxquestions.org
Tags:           xcb
Comments:       Development
                
Change-log:     2024/08/14 v 1.0.1 on 15x
Current:        2024/08/14       
EOF
echo 'libxcb-errors.tcz
libxcb-dev.tcz 
python3.9.tcz      ' > $P-dev.tcz.dep

cat >> $P.tcz.info <<'EOF'
Title:          libxcb-errors.tcz
Description:    XCB utility library below
Version:        1.0.1
Author:         Uli Schlachter 
Original-site:  https://xorg.freedesktop.org/archive/individual/lib/
Copying-policy: accompanied 
Size:           16K 
Extension_by:   aus9 @linuxquestions.org
Tags:           xcb
Comments:       XCB utility library that gives human readable 
                names to error, event & request codes
                
Change-log:     2024/08/14 v 1.0.1 on 15x
Current:        2024/08/14       
EOF
readelf -d $P/usr/local/lib/*.so | grep 'NEEDED' # TCB only
# libxcb.so.1 libxcb

echo 'libxcb.tcz' > $P.tcz.dep
submitqc --libs
rm -rf *.zsync

